<?php
/*
Plugin name: ELEX WooCommerce Product Price Custom Text (Before & After Text) and Discount
Plugin URI: https://elextensions.com/plugin
Description: The plugin simplifies the task to add a text before and after the product price both globally and individually.It also allows you to apply a quick discount for your products.
Version:1.1.0
WC requires at least: 2.6.0
WC tested up to: 5.4
Author: ELEXtensions
Author URI: https://elextensions.com/
Text Domain: elex-product-price-custom-text-and-discount
*/

// to check whether accessed directly
if (!defined('ABSPATH')) {
  exit;
}

//to check whether woocommerce is activated
if (!in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
  die('<b>WooCommerce</b> plugin must be active for <b>WooCommerce Product Price Custom Text & Discount (BASIC)</b> to work.');

}

//setting link for plugin
function elex_ppct_plugin_action_links( $links ) {
	$links = array_merge( array(
    '<a href="' . esc_url( admin_url( 'admin.php?page=wc-settings&tab=elex_ppct_discount' ) ) . '">' . __( 'Settings', 'elex-product-price-custom-text-and-discount' ) . '</a>',
    '<a href="https://elextensions.com/product-category/plugins/" target="_blank">' . __('ELEX Premium Plugins', 'elex-product-price-custom-text-and-discount') . '</a>'
	), $links );
	return $links;
}
add_action( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'elex_ppct_plugin_action_links' );

//submenu in woocommerce
add_action('admin_menu', 'elex_ppct_discount_submenu_page');
function elex_ppct_discount_submenu_page() {
	add_submenu_page( 'woocommerce', 'Product Price Custom Text & Discount', 'Product Price Custom Text & Discount', 'manage_options', 'admin.php?page=wc-settings&tab=elex_ppct_discount');
}

if(isset($_POST['submit']))
{
  if(isset($_POST['elex_ppct_discount_percent'])){
    update_option('elex_ppct_discount_percent',sanitize_text_field($_POST['elex_ppct_discount_percent']));
    update_option('elex_ppct_discount_amount',sanitize_text_field($_POST['elex_ppct_discount_amount']));
    update_option('elex_ppct_prefix_field',sanitize_text_field($_POST['elex_ppct_prefix_field']));
    update_option('elex_ppct_suffix_field',sanitize_text_field($_POST['elex_ppct_suffix_field']));
  }
}

include('includes/elex-ppct-discount-woocommerce-setting.php');
include('includes/elex-ppct-woocmmerce-variation-settings.php');

//fetch data from db
function elex_ppct_discount_product($price,$product) {
 
 if($product->is_type( 'variation' )){
    $product_id = $product->get_parent_id();
    $variation_id = $product->get_id();
  }
 else{
    $product_id = $product->get_id();
  }

  $custom_check_enable=get_post_meta($product_id,'elex_ppct_custom_fields_checkbox',true);
  $check_enable=get_option('elex_ppct_check_field');
  
  if(!empty($variation_id)){
    $discount_variation_percent=get_post_meta($variation_id, 'elex_ppct_variation_discount_percent', true );
    $discount_variation_amount=get_post_meta($variation_id, 'elex_ppct_variation_discount_amount', true );
  }
  
  if( !empty($discount_variation_percent) || !empty($discount_variation_amount)){
    if(is_numeric($discount_variation_amount) && is_numeric($price)){
      $price=($price-((float)$discount_variation_amount));
    }
    if(is_numeric($discount_variation_percent)&& is_numeric($price)){
      $price=($price-($price*((float)$discount_variation_percent/100)));
    }
    return $price;
  }
 
  else if(($custom_check_enable == "yes")){
    $discount_amount=get_post_meta($product_id,'elex_ppct_custom_fields_discount_amount',true);
    if(is_numeric($discount_amount) && is_numeric($price)){
      $price=($price-((float)$discount_amount));
    }
    $discount_percent=get_post_meta($product_id,'elex_ppct_custom_fields_discount_percent',true);
    if(is_numeric($discount_percent) && is_numeric($price)){
      $price=($price-($price*((float)$discount_percent/100)));
    }
    return $price;
  }
  
  else if(($check_enable == "yes")){
    $discount_amount_=get_option('elex_ppct_discount_amount');
    if(is_numeric($discount_amount_)&& is_numeric($price)){
      $price=($price-((float)$discount_amount_));
    }
    $discount_percent_=get_option('elex_ppct_discount_percent');
   if(is_numeric($discount_percent_) && is_numeric($price)){
      $price=($price-($price*((float)$discount_percent_/100)));
    }
    return $price;
  }

  else {
    return $price; 
  }

}

//for simple product price
add_filter('woocommerce_product_get_price', 'elex_ppct_discount_product',8,2);

//for variable product each variation price
add_filter('woocommerce_product_variation_get_regular_price', 'elex_ppct_discount_product', 8, 2);
add_filter('woocommerce_product_variation_get_price', 'elex_ppct_discount_product', 8, 2);

//for range of variable product price
add_filter('woocommerce_variation_prices_price',  'elex_ppct_discount_product', 8,2);
add_filter('woocommerce_get_variation_regular_price',  'elex_ppct_discount_product', 8, 2);

function elex_ppct_display_price($price,$product) {
  if($product->is_type( 'variation' )){
    $product_id = $product->get_parent_id();
  }
  else{
    $product_id = $product->get_id();
  }
  $custom_check_enable=get_post_meta($product_id,'elex_ppct_custom_fields_checkbox',true);
  $check_enable=get_option('elex_ppct_check_field');
 
 if(($custom_check_enable === "yes") && !empty($price)){
    $price_before_text = get_post_meta($product_id,'elex_ppct_custom_fields_prefix',true);
    $price_after_text = get_post_meta($product_id,'elex_ppct_custom_fields_suffix',true);

    $price_before_text_html = get_price_before_text_html($price_before_text);
    $price_after_text_html = get_price_after_text_html($price_after_text);

    $price = $price_before_text_html." ".$price." ".$price_after_text_html;

    return $price;
  }
  else if($check_enable === "yes" && !empty($price)){
    $price_before_text = get_option('elex_ppct_prefix_field');
    $price_after_text = get_option('elex_ppct_suffix_field');

    $price_before_text_html = get_price_before_text_html($price_before_text);
    $price_after_text_html = get_price_after_text_html($price_after_text);

    $price = $price_before_text_html." ".$price." ".$price_after_text_html;
    
      return $price;
  }
  else{
     return $price;
  }
   
}

function get_price_before_text_html($price_before_text) {
  if(!empty($price_before_text)){
    return '<span class="elex-ppct-before-text">'.$price_before_text.'</span>';
  }
  else{
    return $price_before_text;
  }
}

function get_price_after_text_html($price_after_text){
  if(!empty($price_after_text)){
    return '<span class="elex-ppct-after-text">'.$price_after_text.'</span>';
  }
  else{
    return $price_after_text;
  }
}
add_filter('woocommerce_get_price_html', 'elex_ppct_display_price',999,2);

add_filter( 'woocommerce_variable_price_html', 'elex_variation_price_format', 999, 2 );
 function elex_variation_price_format( $price, $product ) {
  // Get min/max regular and sale variation prices
    if($product->is_type( 'variation' )){
      $min_var_reg_price = $product->get_id()->get_variation_regular_price( 'min', true );
      $min_var_sale_price = $product->get_id()->get_variation_sale_price( 'min', true );
      $max_var_reg_price = $product->get_variation_regular_price( 'max', true );
      $max_var_sale_price = $product->get_variation_sale_price( 'max', true );
    }
    
    //  New $price, unless all variations have exact same prices
    if(!empty($min_var_reg_price)||!empty($max_var_reg_price)||!empty( $min_var_sale_price)||!empty( $max_var_sale_price)){
      if ( ! ( $min_var_reg_price == $max_var_reg_price && $min_var_sale_price == $max_var_sale_price ) ) {   
        if ( $min_var_sale_price < $min_var_reg_price ) {
            $price = sprintf( wc_price( $min_var_reg_price ), wc_price( $min_var_sale_price ) )." - ". sprintf( wc_price( $max_var_reg_price ), wc_price( $max_var_sale_price ) );
        } else {
            $price = sprintf( wc_price( $min_var_reg_price ) )." - ".sprintf(  wc_price( $max_var_reg_price ) );
        }
      } 
    }
  
    return $price;
  }
?>